"""
Rebrain - Transform chat history into structured memory graphs.

A system for ingesting, synthesizing, and retrieving personal cognition
from chat exports using dual vector+graph storage.
"""

__version__ = "0.1.2"
__author__ = "Yasin Salimibeni"

__all__ = []

